<?php
/**
 * Fichier functions.php
 * 
 * Ce fichier regroupe toutes les fonctions d'affichage
 * @author Nicolas Loeuillet <nicolas.loeuillet@62actu.net>
 * @version 1.0
 * @package core
 * @license http://www.gnu.org/licenses/gpl-3.0.txt GPL version 3.0 license
 */

/**
 * Formate le solde selon qu'il soit positif ou ngatif
 * @param $solde un solde de compte
 * @return string la chaine formate
 */
function formatSolde($solde)
{
  // TODO rcuprer la devise depuis le fichier grisbi (propre  chaque compte)
  $solde = traiterMontantPourAffichage($solde);
  if ($solde < 0) {
    return '<span style="color:#CF3500;">' . $solde . '</span>';
  }
  else {
  	return '<span style="color:#04A26C;">' . $solde . '</span>';
  }
}

/**
 * Affiche un formulaire de critres pour les oprations
 * @return string le formulaire
 */
function afficherFormulaireCriteresOperations()
{
	global $grisbi;
	$form = '
            <fieldset>
              <legend>'._("Criteres").'</legend>
              <label for="d">Date de d&eacute;but : </label> 
              <input type="text" name="dateDebut" onfocus="if(this.value==\'JJ/MM/AAAA\') this.value=\'\';" onblur="if(this.value==\'\') this.value=\'JJ/MM/AAAA\';" value="'.(isset($_POST['dateDebut']) && $_POST['dateDebut'] != '' ? $_POST['dateDebut'] : 'JJ/MM/AAAA').'" /><br />
              <label for="d">Date de fin : </label> 
              <input type="text" name="dateFin" onfocus="if(this.value==\'JJ/MM/AAAA\') this.value=\'\';" onblur="if(this.value==\'\') this.value=\'JJ/MM/AAAA\';" value="'.(isset($_POST['dateFin']) && $_POST['dateFin'] != '' ? $_POST['dateFin'] : 'JJ/MM/AAAA').'" /><br />
              <label for="mc">'._("Montant au credit").' : </label> 
              <input type="text" name="mc" value="'.(isset($_POST['mc']) && $_POST['mc'] != '' ? $_POST['mc'] : '').'" /><br />
              <label for="md">'._("Montant au debit").' : </label> 
              <input type="text" name="md" value="'.(isset($_POST['md']) && $_POST['md'] != '' ? $_POST['md'] : '').'" /><br />';
  $form .= '<label for="t">'._("Tiers").' : </label><select name="t">
    <option value=""></option>';
	$tabTiers = $grisbi->getLibelleTiers();
	foreach($tabTiers as $tiers)
	{
		$form .= '<option value="' . $tiers['id'] . '" '.(isset($_POST['t']) && $_POST['t'] == $tiers['id'] ? ' selected="selected" ' : '').'>' . $tiers['nom'] . '</option>';
	}
	$form .= '</select><br />
	            <label for="nbOperations">'._("Nombre operations").' : </label>
	            <input type="text" name="nbOperations" value="'.(isset($_POST['nbOperations']) && $_POST['nbOperations'] != '' ? $_POST['nbOperations'] : '').'" /><br />
              <input type="submit" value="'._("Filtrer").'" />
            </fieldset>
	';
	
	return $form;
}

/**
 * Traite les donnes retournes par le formulaire
 * @return array tableau  envoyer au parseur XML pour filtrer les oprations
 */
function traitementDonneesOperations()
{
	$params = array();
  // Traitement des options du filtre
  // date de dbut
  if (isset($_POST['dateDebut']) && $_POST['dateDebut'] != '' && $_POST['dateDebut'] != 'JJ/MM/AAAA') {
    $params['dateDebut'] = $_POST['dateDebut'];
  }
  
  // date de fin
  if (isset($_POST['dateFin']) && $_POST['dateFin'] != '' && $_POST['dateFin'] != 'JJ/MM/AAAA') {
    $params['dateFin'] = $_POST['dateFin'];
  }
  
  // Montant crdit
  if (isset($_POST['mc']) && $_POST['mc'] != '') {
    $params['m'] = traiterMontantPourGrisbi($_POST['mc']);
  }
  
  // Montant dbit 
  if (isset($_POST['md']) && $_POST['md'] != '') {
    $params['m'] = traiterMontantPourGrisbi(-($_POST['md']));
  }
  
  // Tiers
  if (isset($_POST['t']) && $_POST['t'] != '') {
    $params['t'] = $_POST['t'];
  }
  
  return $params;
}

/**
 * N'affique que deux dcimales et un point
 * @param $montant
 * @return string montant format pour l'affichage sur le site
 */
function traiterMontantPourAffichage($montant)
{
  //$montant = sprintf("%01.2f", $montant);
  $montant = str_replace(",", ".", $montant);
  $montant = sprintf("%01.2f", $montant);

  return $montant;
}

/**
 * Formate le montant pour correspondre au format grisbi,  savoir 7 dcimales et une virgule
 * @param $montant
 * @return string montant format pour le parseur XML
 */
function traiterMontantPourGrisbi($montant)
{
  $montant = sprintf("%01.7f", $montant);
  $montant = str_replace(".", ",", $montant);

	return $montant;
}

/**
 * Affiche une catgorie et, le cas chant, la sous-catgorie associe
 * @param $categorie la chaine de caractres de la catgorie
 * @param $sousCategorie la chaine de caractres de la sous-catgorie
 * @return string la chaine formate
 */
function formatCategorie($categorie, $sousCategorie)
{
	$toReturn = $categorie;
	if ($sousCategorie != '') {
		$toReturn .= ' : ' . $sousCategorie;
	}
	
	return $toReturn;
}

/**
 * Retourne une date au format timestamp passe en paramtre 
 * @param $date la date  convertir en timestamp
 * @return int la date en timestamp
 */
function convertirTimestamp($date)
{
	$timestamp = split("[/.-]", $date);
	$timestamp = mktime(0,0,0, $timestamp[1], $timestamp[0], $timestamp[2]);
	return $timestamp;
}

/**
 * Retourne la version du logiciel
 * @return string la chaine formate 
 */
function getVersion()
{
  global $versionLogiciel;
	
  return _("Grisbiweb") . ' ' .$versionLogiciel;
}

/**
 * Retourne les copyrights du logiciel
 * @return string la chaine formate
 */
function getCopyrights()
{
  return getVersion() . ' par <a href="http://www.grisbiweb.org/">Nicolas Loeuillet</a>';
}
?>
